# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mempool_status.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='mempool_status.proto',
  package='mempool',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x14mempool_status.proto\x12\x07mempool*\x96\x01\n\x1bMempoolAddTransactionStatus\x12\t\n\x05Valid\x10\x00\x12\x17\n\x13InsufficientBalance\x10\x01\x12\x14\n\x10InvalidSeqNumber\x10\x02\x12\x11\n\rMempoolIsFull\x10\x03\x12\x17\n\x13TooManyTransactions\x10\x04\x12\x11\n\rInvalidUpdate\x10\x05\x62\x06proto3')
)

_MEMPOOLADDTRANSACTIONSTATUS = _descriptor.EnumDescriptor(
  name='MempoolAddTransactionStatus',
  full_name='mempool.MempoolAddTransactionStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Valid', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InsufficientBalance', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InvalidSeqNumber', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MempoolIsFull', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TooManyTransactions', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InvalidUpdate', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=34,
  serialized_end=184,
)
_sym_db.RegisterEnumDescriptor(_MEMPOOLADDTRANSACTIONSTATUS)

MempoolAddTransactionStatus = enum_type_wrapper.EnumTypeWrapper(_MEMPOOLADDTRANSACTIONSTATUS)
Valid = 0
InsufficientBalance = 1
InvalidSeqNumber = 2
MempoolIsFull = 3
TooManyTransactions = 4
InvalidUpdate = 5


DESCRIPTOR.enum_types_by_name['MempoolAddTransactionStatus'] = _MEMPOOLADDTRANSACTIONSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


# @@protoc_insertion_point(module_scope)
